@@ -17,10 +17,10 @@ setClass("SimDataDist", representation(p = "numeric", margins = "character", par
 setClass("SimResult", representation(modelType = "character", nRep = "numeric", coef = "data.frame", 
     se = "data.frame", fit = "data.frame", converged = "vector", paramValue = "data.frame", 
     misspecValue = "data.frame", popFit = "data.frame", FMI1 = "data.frame", FMI2 = "data.frame", 
-    stdCoef = "data.frame", seed = "numeric", n = "vector", pmMCAR = "vector", pmMAR = "vector", 
-    extraOut = "list", timing = "list"))
+    stdCoef = "data.frame", seed = "numeric", n = "vector", nobs="data.frame", pmMCAR = "vector", pmMAR = "vector", 
+    extraOut = "list", paramOnly = "logical", timing = "list"))
 
-setClass("SimMissing", representation(cov = "vector", pmMCAR = "numeric", pmMAR = "numeric", 
+setClass("SimMissing", representation(cov = "vector", pmMCAR = "numeric", pmMAR = "numeric", logit = "character", 
     nforms = "numeric", itemGroups = "list", twoMethod = "vector", prAttr = "vector", m = "numeric", chi = "character", 
     package = "character", convergentCutoff = "numeric", timePoints = "numeric", ignoreCols = "vector", threshold = "numeric", 
     covAsAux = "logical", logical = "matrix", args = "list")) 
