@@ -75,11 +75,12 @@ setMethod("getPowerFit", signature(altObject = "matrix", cutoff = "vector"), def
 })
 
 setMethod("getPowerFit", signature(altObject = "SimResult", cutoff = "missing"), 
-    definition = function(altObject, cutoff = NULL, nullObject, revDirec = FALSE, 
+    definition = function(altObject, cutoff = NULL, nullObject = NULL, revDirec = FALSE, 
         usedFit = NULL, alpha = 0.05, nVal = NULL, pmMCARval = NULL, pmMARval = NULL, 
         df = 0) {
         if (is.null(usedFit)) 
             usedFit <- getKeywords()$usedFit
+		if(is.null(nullObject)) nullObject <- altObject
         mod <- clean(altObject, nullObject)
         altObject <- mod[[1]]
         nullObject <- mod[[2]]
@@ -127,6 +128,11 @@ setMethod("getPowerFit", signature(altObject = "SimResult", cutoff = "missing"),
             usedCutoff <- as.vector(t(getCutoff(nullObject, alpha = alpha, usedFit = usedFit)))
             names(usedCutoff) <- usedFit
             temp <- pValue(usedCutoff, as.data.frame(usedDist), revDirec = usedDirec)
+			names(temp) <- usedFit
+			# Find cutoff based on chi-square test
+			cutoffChisq <- qchisq(1 - alpha, df=nullObject@fit[,"df"])
+			powerChi <- mean(altObject@fit[,"Chi"] > cutoffChisq)
+			temp <- c("TraditionalChi" = powerChi, temp)
         } else {
             varyingCutoff <- getCutoff(object = nullFit, alpha = alpha, revDirec = FALSE, 
                 usedFit = usedFit, predictor = condValue, df = df, predictorVal = "all")
@@ -134,7 +140,7 @@ setMethod("getPowerFit", signature(altObject = "SimResult", cutoff = "missing"),
                 temp[i] <- pValueVariedCutoff(varyingCutoff[, i], usedDist[, i], 
                   revDirec = usedDirec[i], x = condValue, xval = predictorVal)
             }
+			names(temp) <- usedFit
         }
-        names(temp) <- usedFit
         return(temp)
     }) 
